Learn R Programming

userfriendlyscience (version 0.7.2)

sort.associationMatrix: sort.associationMatrix

Description

This function sorts an associationMatrix ascendingly or descendingly by one of its columns.

Usage

# S3 method for associationMatrix
sort(x, decreasing = TRUE, byColumn = 1, ...)

Arguments

x

The associationMatrix object to sort.

decreasing

Whether to sort ascendingly (FALSE) or descending (TRUE).

byColumn

Which column to sort the matrix by, as an index.

…

Passed on to sort.

Value

The associationMatrix, but sorted.

Details

Note that if the associationMatrix contains values of different effectsizes, the sorting may be misleading. For example, a value of Cohen's d of .45 is higher than a value of Pearson's r of .35, and so will end up higher in a 'decreasing' sort - even though the association represented by an r of .35 is stronger than that represented by a d of .45.

Furthermore, only asymmetrical associationMatrices can be sorted; sorting a symmetrical association matrix would also change the order of the columns, after all.

See Also

associationMatrix

Examples

Run this code
# NOT RUN {
sort(associationMatrix(infert, y=c("parity", "age"),
                       x=c("induced", "case", "spontaneous"), colNames=TRUE));
# }

Run the code above in your browser using DataLab